@@ -498,7 +498,7 @@ format.tbl_ts <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
       "`.data`. is a corrupt tsibble object.",
       i = "Please reconstruct with `as_tsibble()`."))
   }
-  format(trunc_mat(x, n = n, width = width, n_extra = n_extra))
+  NextMethod()
 }
 
 #' Coerce to a tibble or data frame
